// application
const express = require("express");

const app = express();
app.use(express.json());

const { getUsers, getUserById } = require("./service/user");

// swagger config
const swaggerUi = require("swagger-ui-express"),
  swaggerDoc = require("./swagger.json");

// application routes

// get all users
// endpoint = http://localhost:6001/users
app.get("/users", (req, res) => {
  return res.status(200).json({
    status: "ok",
    item: getUsers()
  });
});

// get user by id
// endpoint = http://localhost:6001/user?id=1
app.get("/user", (req, res) => {
  let id = req.query.id;
  const user = getUserById(id);
  if (!user) {
    return res.status(404).json({
      status: "not found",
      message: "resource not found"
    });
  } else {
    return res.status(200).json({
      status: "ok",
      item: user
    });
  }
});

// setting up swagger
// endpoint = http://localhost:6001/api-docs/
app.use("/api-docs", swaggerUi.serve, swaggerUi.setup(swaggerDoc));

// start application
const port = process.env.PORT || 6001;
app.listen(port, () => {
  console.log(`Service endpoint = http://localhost:${port}`);
});
